#
# spec file for package ocaml-qcheck
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with ocaml_qcheck_testsuite
%define build_flavor %nil
%if "%build_flavor" == "testsuite"
%if %{without ocaml_qcheck_testsuite}
ExclusiveArch:  do-not-build
%else
ExclusiveArch:  aarch64 ppc64 ppc64le riscv64 s390x x86_64
%endif
%define nsuffix -testsuite
%else
%define nsuffix %nil
ExclusiveArch:  aarch64 ppc64 ppc64le riscv64 s390x x86_64
%endif

%define     pkg ocaml-qcheck
Name:           %pkg%nsuffix
Version:        0.21.3
Release:        1.3
%{?ocaml_preserve_bytecode}
Summary:        QuickCheck inspired property-based testing for OCaml
License:        BSD-2-Clause
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/qcheck
Source0:        %pkg-%version.tar.xz
BuildRequires:  ocaml(ocaml_base_version) >= 4.08
BuildRequires:  ocaml-dune >= 2.8
BuildRequires:  ocaml-rpm-macros >= 20231101
BuildRequires:  ocamlfind(ounit2)
BuildRequires:  ocamlfind(ppxlib)
BuildRequires:  ocamlfind(ppx_deriving)
BuildRequires:  ocamlfind(unix)

%if "%build_flavor" == "testsuite"
BuildRequires:  ocamlfind(alcotest)
BuildRequires:  ocamlfind(qcheck)
%endif

%description
This module allows to check invariants (properties of some types) over
randomly generated instances of the type. It provides combinators for
generating instances and printing them.

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.


%prep
%autosetup -p1 -n %pkg-%version

%build
dune_release_pkgs='qcheck,qcheck-core,qcheck-ounit,ppx_deriving_qcheck'
%if "%build_flavor" == "testsuite"
dune_release_pkgs="${dune_release_pkgs},qcheck-alcotest"
%endif
%ocaml_dune_setup
%if "%build_flavor" == ""
%ocaml_dune_build
%endif

%install
%if "%build_flavor" == ""
%ocaml_dune_install
%ocaml_create_file_list
%endif

%if "%build_flavor" == "testsuite"
%check
%ocaml_dune_test
%endif

%if "%build_flavor" == ""
%files -f %name.files
%doc README.adoc

%files devel -f %name.files.devel
%endif

%changelog
* Tue Dec 12 2023 ohering@suse.de
- Update to version 0.21.3
  see included CHANGELOG.md file for details
* Sat Sep  9 2023 ohering@suse.de
- Update to version 0.21.2
  See included CHANGELOG.md for details
* Sun May 21 2023 ohering@suse.de
- Update to version 0.21.1
  See included CHANGELOG.md for details
* Fri May  5 2023 ohering@suse.de
- Update to version 0.21
  See included CHANGELOG.md for details
* Sun Jan  1 2023 ohering@suse.de
- Update to version 0.20
  See included CHANGELOG.md for details
* Mon Apr  4 2022 ohering@suse.de
- Update to version 0.18.1
  See included CHANGELOG.md for details
* Sat Sep 11 2021 ohering@suse.de
- Update to version 0.18
  See included CHANGELOG.md for details
* Thu Jan 21 2021 ohering@suse.de
- Update to version 0.17
  See included CHANGELOG.md for details
* Thu Aug 20 2020 ohering@suse.de
- Update to version 0.14
  See included CHANGELOG.md for details
* Thu Feb 20 2020 ohering@suse.de
- Require current dune macros
- Build conditionally with ocaml-alcotest
* Mon Sep 30 2019 ohering@suse.de
- use dune macros from ocaml-rpm-macros
* Mon Sep 23 2019 ohering@suse.de
- Update to version 0.10
* Mon Sep 23 2019 ohering@suse.de
- Expand filelist to fix build
* Tue Feb 19 2019 andy@onthewings.net
- Update install section for ocaml-dune 1.7.1.
- BuildRequires: opam-installer instead of opam to be accurate.
* Fri Feb  8 2019 andy@onthewings.net
- New upstream version (0.9).
  * Add TestResult.is_success helper.
  * Give access to list of instances in test results.
  * Allow setting time_between_msg in runner.
  * Update docs.
- Updated build commands for the new dune version.
* Mon Jun 11 2018 andy@onthewings.net
- Package the .ml and .dune files produced with latest dune.
* Fri Mar  9 2018 andy@onthewings.net
- Initial packaging.
